.. module:: enaml.layout.dock_layout

========================
enaml.layout.dock_layout
========================

.. rubric:: Classes

.. autosummary::
    :nosignatures:

    AreaLayout
    DockBarLayout
    DockLayout
    DockLayoutOp
    DockLayoutValidator
    DockLayoutWarning
    ExtendItem
    FloatArea
    FloatItem
    HSplitLayout
    InsertItem
    InsertBorderItem
    InsertDockBarItem
    InsertTab
    ItemLayout
    LayoutNode
    RemoveItem
    RetractItem
    SplitLayout
    TabLayout
    VSplitLayout


.. autoclass:: AreaLayout

.. autoclass:: DockBarLayout

.. autoclass:: DockLayout

.. autoclass:: DockLayoutOp

.. autoclass:: DockLayoutValidator

.. autoclass:: DockLayoutWarning

.. autoclass:: ExtendItem

.. autoclass:: FloatArea

.. autoclass:: FloatItem

.. autoclass:: HSplitLayout

.. autoclass:: InsertItem

.. autoclass:: InsertBorderItem

.. autoclass:: InsertDockBarItem

.. autoclass:: InsertTab

.. autoclass:: ItemLayout

.. autoclass:: LayoutNode

.. autoclass:: RemoveItem

.. autoclass:: RetractItem

.. autoclass:: SplitLayout

.. autoclass:: TabLayout

.. autoclass:: VSplitLayout
